/*
** Module   : ComboBoxSimpleListGuiImpl.java
** Abstract : Simple list for combo-box panel GUI implementation. 
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 EVL 20150610 Initial version.
*/

package com.goldencode.p2j.ui.client.gui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.event.*;
import com.goldencode.p2j.ui.client.gui.driver.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * A simple list for combo-box panel GUI implementation. 
 */
@SuppressWarnings("unchecked")
public class ComboBoxSimpleListGuiImpl
extends ScrollPaneGuiImpl
{
   /** Combo-box reference the list is attached to. */
   private ComboBoxGuiImpl comboBoxRef = null;
   
   /**
    * Constructor.
    * 
    * @param   id
    *          The widget's ID.
    * @param   widget
    *          Child widget.
    */
   ComboBoxSimpleListGuiImpl(WidgetId id, Widget<GuiOutputManager> widget)
   {
      super(id, widget);
   }

   /**
    * Constructor.
    * 
    * @param   cbbRef
    *          The reference to the combo-box.
    */
   ComboBoxSimpleListGuiImpl(WidgetId id, Widget<GuiOutputManager> widget, ComboBoxGuiImpl cbbRef)
   {
      this(id, widget);
      // setting up internals
      comboBoxRef = cbbRef;
   }

   /**
    * This method is invoked when scroll pane is scrolled.
    * Scroll events could coming from both scroll bars or from contained widget.
    * 
    * @param   event
    *          Event which triggered this call.
    */
   @Override
   public void scroll(ScrollEvent event)
   {
      // call superclass first
      super.scroll(event);

      // then combo-box specific, find out if the key or mouse scrolling,
      // key scroll causes the combo-box value to be changed
      if (!event.isMouseOrigin())
      {
         // and simulate ENTER key for child selection list to select it
         KeyInput ki = new KeyInput(getChild(), EventType.KEY_PRESSED, Key.VK_ENTER);
         EventManager.postEvent(ki);
      }
   }
}
